# PyGaze - the open-source toolbox for eye tracking

*Copyright 2013 - 2022, Edwin Dalmaijer, Sebastiaan Mathôt, and contributors*

For more information, see: <https://www.pygaze.org/contributors>


## Citation

* Dalmaijer, E.S., Mathôt, S., & Van der Stigchel, S. (2013). PyGaze: an open-source, cross-platform toolbox for minimal-effort programming of eye tracking experiments. *Behaviour Research Methods*. doi:[10.3758/s13428-013-0422-2](http://link.springer.com/article/10.3758%2Fs13428-013-0422-2)


## Documentation

- <https://pygaze.org/>
- <https://osdoc.cogsci.nl/manual/eyetracking/pygaze/>


## Installation

```
pip install python-pygaze
```


## License

PyGaze is open source software and therefore free to use and modify at will.
Warranty, however, is NOT given. If this software fails, causes your computer
to blow up, your spouse to leave you, your toilet to clog and/or the entire
supply of nuclear missles on earth to launch, or anything else that you might
want to blame on us, the author(s) CANNOT IN ANY WAY be held responsible.

PyGaze was released under the GNU Public License (version 3), of which you
should have received a copy of together with the software:

    PyGaze is a Python package for easily creating gaze contingent experiments
    or other software (as well as non-gaze contingent experiments/software)
    Copyright (C) 2012-2020 Edwin S. Dalmaijer

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>

I hope PyGaze proves to be helpful to you!
